dbuscon

package
v0.0.0-...-080cee2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 7, 2026 License: GPL-3.0 Imports: 4 Imported by: 0

README

DBUS Bindings

These files are automatically generated from the respective dbus spec .xml files.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Client

type Client struct {
	// contains filtered or unexported fields
}

func NewDbusClient

func NewDbusClient() *Client

func (*Client) Connect

func (d *Client) Connect() error

func (*Client) Connected

func (d *Client) Connected() (*dbus.Conn, bool)

Connected returns whether the bus connection is established or not

func (*Client) GetConnection

func (d *Client) GetConnection() *dbus.Conn

func (*Client) Reconnect

func (d *Client) Reconnect() error

Reconnect re-establishes the system connection if its down

func (*Client) Shutdown

func (d *Client) Shutdown() (err error)

type NotConnectedError

type NotConnectedError struct{}

func (*NotConnectedError) Error

func (e *NotConnectedError) Error() string

func (*NotConnectedError) Is

func (e *NotConnectedError) Is(target error) bool

Directories

Path Synopsis

Jump to